package com.yijia.station.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yijia.station.mapper.StationClassesSummaryMapper;
import com.yijia.station.domain.StationClassesSummary;
import com.yijia.station.service.IStationClassesSummaryService;

/**
 * 【请填写功能名称】Service业务层处理
 * 
 * @author yijia
 * @date 2020-12-28
 */
@Service
public class StationClassesSummaryServiceImpl implements IStationClassesSummaryService 
{
    @Autowired
    private StationClassesSummaryMapper stationClassesSummaryMapper;

    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】ID
     * @return 【请填写功能名称】
     */
    @Override
    public StationClassesSummary selectStationClassesSummaryById(Long id)
    {
        return stationClassesSummaryMapper.selectStationClassesSummaryById(id);
    }

    @Override
    public StationClassesSummary selectStationClassesSummary(StationClassesSummary stationClassesSummary) {
        return stationClassesSummaryMapper.selectStationClassesSummary(stationClassesSummary);
    }

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param stationClassesSummary 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<StationClassesSummary> selectStationClassesSummaryList(StationClassesSummary stationClassesSummary)
    {
        return stationClassesSummaryMapper.selectStationClassesSummaryList(stationClassesSummary);
    }

    /**
     * 新增【请填写功能名称】
     * 
     * @param stationClassesSummary 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertStationClassesSummary(StationClassesSummary stationClassesSummary)
    {
        return stationClassesSummaryMapper.insertStationClassesSummary(stationClassesSummary);
    }

    /**
     * 修改【请填写功能名称】
     * 
     * @param stationClassesSummary 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateStationClassesSummary(StationClassesSummary stationClassesSummary)
    {
        return stationClassesSummaryMapper.updateStationClassesSummary(stationClassesSummary);
    }

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的【请填写功能名称】ID
     * @return 结果
     */
    @Override
    public int deleteStationClassesSummaryByIds(Long[] ids)
    {
        return stationClassesSummaryMapper.deleteStationClassesSummaryByIds(ids);
    }

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param id 【请填写功能名称】ID
     * @return 结果
     */
    @Override
    public int deleteStationClassesSummaryById(Long id)
    {
        return stationClassesSummaryMapper.deleteStationClassesSummaryById(id);
    }
}
